@@ -318,6 +318,8 @@ class FS(object):
         with self._lock:
             if not create and not self.exists(dst_path):
                 raise errors.ResourceNotFound(dst_path)
+            if not self.getinfo(src_path).is_dir:
+                raise errors.DirectoryExpected(src_path)
             copy.copy_dir(
                 self,
                 src_path,
@@ -513,7 +515,7 @@ class FS(object):
         specified with the `namespace` parameter. The default namespace,
         ``"standard"``, contains common information regarding the
         filesystem's capabilities. Some filesystems may provide other
-        namespaces, which expose less common, or implementation specific
+        namespaces which expose less common or implementation specific
         information. If a requested namespace is not supported by
         a filesystem, then an empty dictionary will be returned.
 
@@ -522,7 +524,7 @@ class FS(object):
         =================== ============================================
         key                 Description
         ------------------- --------------------------------------------
-        case_insensitive    True if this filesystem is case sensitive.
+        case_insensitive    True if this filesystem is case insensitive.
         invalid_path_chars  A string containing the characters that may
                             may not be used on this filesystem.
         max_path_length     Maximum number of characters permitted in a
@@ -535,6 +537,10 @@ class FS(object):
                             os.rename operation.
         =================== ============================================
 
+        Most builtin filesystems will provide all these keys, and third-
+        party filesystems should do so whenever possible, but a key may
+        not be present if there is no way to know the value.
+
         .. note::
             Meta information is constant for the lifetime of the
             filesystem, and may be cached.
@@ -542,7 +548,7 @@ class FS(object):
 
         """
         if namespace == 'standard':
-            meta = self._meta
+            meta = self._meta.copy()
         else:
             meta = {}
         return meta
@@ -820,6 +826,8 @@ class FS(object):
 
         if not overwrite and self.exists(dst_path):
             raise errors.DestinationExists(dst_path)
+        if self.getinfo(src_path).is_dir:
+            raise errors.FileExpected(src_path)
         if self.getmeta().get('supports_rename', False):
             try:
                 src_sys_path = self.getsyspath(src_path)
