@@ -1,10 +1,12 @@
 # coding: utf-8
 """Defines the TarOpener."""
 
-from ._base import Opener
-from ._registry import registry
+from __future__ import absolute_import
+from __future__ import print_function
+from __future__ import unicode_literals
+
+from .base import Opener
 
-@registry.install
 class TarOpener(Opener):
     protocols = ['tar']
 
